#ifdef DECL_SIGNATURE_TABLE
PrototypeDescriptor(1, 0, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(1, 0, 11),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(1, 0, 3),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 32),
PrototypeDescriptor(2, 1, 32),
PrototypeDescriptor(2, 0, 128),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 9, 136),
PrototypeDescriptor(2, 9, 8),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 9, 136),
PrototypeDescriptor(2, 9, 0),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 9, 128),
PrototypeDescriptor(2, 9, 8),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 1, 0),
PrototypeDescriptor(2, 9, 128),
PrototypeDescriptor(2, 9, 0),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 32),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 2, 32),
PrototypeDescriptor(8, 0, 0),
PrototypeDescriptor(6, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 2, 32),
PrototypeDescriptor(8, 0, 0),
PrototypeDescriptor(6, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 9, 136),
PrototypeDescriptor(2, 9, 8),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 9, 136),
PrototypeDescriptor(2, 9, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 9, 128),
PrototypeDescriptor(2, 9, 8),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 9, 128),
PrototypeDescriptor(2, 9, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 32),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 32),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 32),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 32),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 1, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 32),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(1, 0, 8),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 0, 8),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(3, 0, 0),
PrototypeDescriptor(4, 0, 4),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(2, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
PrototypeDescriptor(4, 0, 0),
#endif
#ifdef DECL_INTRINSIC_RECORDS
{/*Name=*/"sf_vqmaccu_2x8x2", /*OverloadedName=*/"sf_vqmaccu_2x8x2", /*RequiredExtensions=*/"xsfvqmaccdod", /*PrototypeIndex=*/61, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/120, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_x", /*OverloadedName=*/"sf_vc_v_x", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/41, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_x_se", /*OverloadedName=*/"sf_vc_x_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/190, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_x_se", /*OverloadedName=*/"sf_vc_x_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/190, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_x_se", /*OverloadedName=*/"sf_vc_x_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/190, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_x_se", /*OverloadedName=*/"sf_vc_x_se", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/190, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_i_se", /*OverloadedName=*/"sf_vc_i_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/183, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_xv_se", /*OverloadedName=*/"sf_vc_xv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/92, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_xv_se", /*OverloadedName=*/"sf_vc_xv_se", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/92, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_iv_se", /*OverloadedName=*/"sf_vc_iv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/77, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_iv_se", /*OverloadedName=*/"sf_vc_iv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/77, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_vv_se", /*OverloadedName=*/"sf_vc_vv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/82, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_vv_se", /*OverloadedName=*/"sf_vc_vv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/82, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_fv_se", /*OverloadedName=*/"sf_vc_fv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/87, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_fv_se", /*OverloadedName=*/"sf_vc_fv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/87, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_xvv_se", /*OverloadedName=*/"sf_vc_xvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/132, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_xvv_se", /*OverloadedName=*/"sf_vc_xvv_se", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/132, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_ivv_se", /*OverloadedName=*/"sf_vc_ivv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/117, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_ivv_se", /*OverloadedName=*/"sf_vc_ivv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/117, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_vvv_se", /*OverloadedName=*/"sf_vc_vvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/122, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_vvv_se", /*OverloadedName=*/"sf_vc_vvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/122, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_fvv_se", /*OverloadedName=*/"sf_vc_fvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/127, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_fvv_se", /*OverloadedName=*/"sf_vc_fvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/127, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_x_se", /*OverloadedName=*/"sf_vc_v_x_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/41, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_x", /*OverloadedName=*/"sf_vc_v_x", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/41, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_x_se", /*OverloadedName=*/"sf_vc_v_x_se", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/41, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_i", /*OverloadedName=*/"sf_vc_v_i", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/37, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_i_se", /*OverloadedName=*/"sf_vc_v_i_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/37, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_i", /*OverloadedName=*/"sf_vc_v_i", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/37, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_i_se", /*OverloadedName=*/"sf_vc_v_i_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/37, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xv", /*OverloadedName=*/"sf_vc_v_xv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/49, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xv_se", /*OverloadedName=*/"sf_vc_v_xv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/49, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xv", /*OverloadedName=*/"sf_vc_v_xv", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/49, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xv_se", /*OverloadedName=*/"sf_vc_v_xv_se", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/49, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_iv", /*OverloadedName=*/"sf_vc_v_iv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/160, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_iv_se", /*OverloadedName=*/"sf_vc_v_iv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/160, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_iv", /*OverloadedName=*/"sf_vc_v_iv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/160, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_iv_se", /*OverloadedName=*/"sf_vc_v_iv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/160, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vv", /*OverloadedName=*/"sf_vc_v_vv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vv_se", /*OverloadedName=*/"sf_vc_v_vv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vv", /*OverloadedName=*/"sf_vc_v_vv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vv_se", /*OverloadedName=*/"sf_vc_v_vv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fv", /*OverloadedName=*/"sf_vc_v_fv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/45, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fv_se", /*OverloadedName=*/"sf_vc_v_fv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/45, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fv", /*OverloadedName=*/"sf_vc_v_fv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/45, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fv_se", /*OverloadedName=*/"sf_vc_v_fv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/45, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xvv", /*OverloadedName=*/"sf_vc_v_xvv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/172, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xvv_se", /*OverloadedName=*/"sf_vc_v_xvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/172, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xvv", /*OverloadedName=*/"sf_vc_v_xvv", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/172, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xvv_se", /*OverloadedName=*/"sf_vc_v_xvv_se", /*RequiredExtensions=*/"xsfvcp,64bit", /*PrototypeIndex=*/172, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_ivv", /*OverloadedName=*/"sf_vc_v_ivv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_ivv_se", /*OverloadedName=*/"sf_vc_v_ivv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_ivv", /*OverloadedName=*/"sf_vc_v_ivv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_ivv_se", /*OverloadedName=*/"sf_vc_v_ivv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/157, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vvv", /*OverloadedName=*/"sf_vc_v_vvv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/162, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vvv_se", /*OverloadedName=*/"sf_vc_v_vvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/162, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vvv", /*OverloadedName=*/"sf_vc_v_vvv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/162, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vvv_se", /*OverloadedName=*/"sf_vc_v_vvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/162, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fvv", /*OverloadedName=*/"sf_vc_v_fvv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/167, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fvv_se", /*OverloadedName=*/"sf_vc_v_fvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/167, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fvv", /*OverloadedName=*/"sf_vc_v_fvv", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/167, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fvv_se", /*OverloadedName=*/"sf_vc_v_fvv_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/167, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/127, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_xvw_se", /*OverloadedName=*/"sf_vc_xvw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/112, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_ivw_se", /*OverloadedName=*/"sf_vc_ivw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/97, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_vvw_se", /*OverloadedName=*/"sf_vc_vvw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/102, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_fvw_se", /*OverloadedName=*/"sf_vc_fvw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/107, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xvw", /*OverloadedName=*/"sf_vc_v_xvw", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/152, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_xvw_se", /*OverloadedName=*/"sf_vc_v_xvw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/152, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_ivw", /*OverloadedName=*/"sf_vc_v_ivw", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/137, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_ivw_se", /*OverloadedName=*/"sf_vc_v_ivw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/137, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vvw", /*OverloadedName=*/"sf_vc_v_vvw", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/142, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_vvw_se", /*OverloadedName=*/"sf_vc_v_vvw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/142, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/7, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fvw", /*OverloadedName=*/"sf_vc_v_fvw", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/147, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vc_v_fvw_se", /*OverloadedName=*/"sf_vc_v_fvw_se", /*RequiredExtensions=*/"xsfvcp", /*PrototypeIndex=*/147, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/5, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/6, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfnrclip_x_f_qf", /*OverloadedName=*/"sf_vfnrclip_x_f_qf", /*RequiredExtensions=*/"xsfvfnrclipxfqf", /*PrototypeIndex=*/57, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/1, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmacc_2x8x2", /*OverloadedName=*/"sf_vqmacc_2x8x2", /*RequiredExtensions=*/"xsfvqmaccdod", /*PrototypeIndex=*/73, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/120, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmaccus_2x8x2", /*OverloadedName=*/"sf_vqmaccus_2x8x2", /*RequiredExtensions=*/"xsfvqmaccdod", /*PrototypeIndex=*/65, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/120, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmaccsu_2x8x2", /*OverloadedName=*/"sf_vqmaccsu_2x8x2", /*RequiredExtensions=*/"xsfvqmaccdod", /*PrototypeIndex=*/69, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/120, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmaccu_4x8x4", /*OverloadedName=*/"sf_vqmaccu_4x8x4", /*RequiredExtensions=*/"xsfvqmaccqoq", /*PrototypeIndex=*/21, /*SuffixIndex=*/21, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/60, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmacc_4x8x4", /*OverloadedName=*/"sf_vqmacc_4x8x4", /*RequiredExtensions=*/"xsfvqmaccqoq", /*PrototypeIndex=*/33, /*SuffixIndex=*/21, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/60, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmaccus_4x8x4", /*OverloadedName=*/"sf_vqmaccus_4x8x4", /*RequiredExtensions=*/"xsfvqmaccqoq", /*PrototypeIndex=*/25, /*SuffixIndex=*/21, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/60, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vqmaccsu_4x8x4", /*OverloadedName=*/"sf_vqmaccsu_4x8x4", /*RequiredExtensions=*/"xsfvqmaccqoq", /*PrototypeIndex=*/29, /*SuffixIndex=*/21, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/60, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfexp_v", /*OverloadedName=*/"sf_vfexp", /*RequiredExtensions=*/"xsfvfbfexp16e", /*PrototypeIndex=*/61, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/126, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfexp_v", /*OverloadedName=*/"sf_vfexp", /*RequiredExtensions=*/"xsfvfexp16e", /*PrototypeIndex=*/61, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/32, /*Log2LMULMask=*/126, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfexp_v", /*OverloadedName=*/"sf_vfexp", /*RequiredExtensions=*/"xsfvfexp32e", /*PrototypeIndex=*/61, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/64, /*Log2LMULMask=*/126, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfexpa_v", /*OverloadedName=*/"sf_vfexpa", /*RequiredExtensions=*/"xsfvfexpa", /*PrototypeIndex=*/61, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/96, /*Log2LMULMask=*/126, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfexpa_v", /*OverloadedName=*/"sf_vfexpa", /*RequiredExtensions=*/"xsfvfexpa64e", /*PrototypeIndex=*/61, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/128, /*Log2LMULMask=*/126, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfwmacc_4x4x4", /*OverloadedName=*/"sf_vfwmacc_4x4x4", /*RequiredExtensions=*/"xsfvfwmaccqqq", /*PrototypeIndex=*/17, /*SuffixIndex=*/17, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/62, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPolicyOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfnrclip_xu_f_qf", /*OverloadedName=*/"sf_vfnrclip_xu_f_qf", /*RequiredExtensions=*/"xsfvfnrclipxfqf", /*PrototypeIndex=*/53, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/1, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfnrclip_x_f_qf", /*OverloadedName=*/"sf_vfnrclip_x_f_qf", /*RequiredExtensions=*/"xsfvfnrclipxfqf", /*PrototypeIndex=*/57, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vfnrclip_xu_f_qf", /*OverloadedName=*/"sf_vfnrclip_xu_f_qf", /*RequiredExtensions=*/"xsfvfnrclipxfqf", /*PrototypeIndex=*/53, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/63, /*NF=*/1, /*HasMasked=*/1, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/HasPassthruOperand, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte8", /*OverloadedName=*/"sf_vlte8", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte8", /*OverloadedName=*/"sf_vlte8", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtzero_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/177, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/6, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtdiscard", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/1, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/1, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/200, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/200, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/200, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/200, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase,zvfhmin", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/32, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase,zvfbfmin", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/64, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_v_t", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/207, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/2, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/128, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/1, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/1, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/1, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/1, /*SuffixIndex=*/3, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase,zvfhmin", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/32, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase,zvfbfmin", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/64, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vtmv_t_v", /*OverloadedName=*/"sf_vtmv_t_v", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/4, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/128, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte16", /*OverloadedName=*/"sf_vlte16", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte16", /*OverloadedName=*/"sf_vlte16", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte16", /*OverloadedName=*/"sf_vlte16", /*RequiredExtensions=*/"xsfmmbase,zvfhmin", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/32, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte16", /*OverloadedName=*/"sf_vlte16", /*RequiredExtensions=*/"xsfmmbase,zvfbfmin", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte32", /*OverloadedName=*/"sf_vlte32", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte32", /*OverloadedName=*/"sf_vlte32", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte32", /*OverloadedName=*/"sf_vlte32", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/64, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte64", /*OverloadedName=*/"sf_vlte64", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte64", /*OverloadedName=*/"sf_vlte64", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vlte64", /*OverloadedName=*/"sf_vlte64", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/128, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste8", /*OverloadedName=*/"sf_vste8", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste8", /*OverloadedName=*/"sf_vste8", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste16", /*OverloadedName=*/"sf_vste16", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste16", /*OverloadedName=*/"sf_vste16", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/2, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste16", /*OverloadedName=*/"sf_vste16", /*RequiredExtensions=*/"xsfmmbase,zvfhmin", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/32, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste16", /*OverloadedName=*/"sf_vste16", /*RequiredExtensions=*/"xsfmmbase,zvfbfmin", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste32", /*OverloadedName=*/"sf_vste32", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste32", /*OverloadedName=*/"sf_vste32", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste32", /*OverloadedName=*/"sf_vste32", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/64, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste64", /*OverloadedName=*/"sf_vste64", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste64", /*OverloadedName=*/"sf_vste64", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/7, /*SuffixIndex=*/44, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/8, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vste64", /*OverloadedName=*/"sf_vste64", /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/10, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/3, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/128, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/1, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_u_u_w4", /*OverloadedName=*/"sf_mm_u_u", /*RequiredExtensions=*/"xsfmm32a8i", /*PrototypeIndex=*/197, /*SuffixIndex=*/85, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_s_u_w4", /*OverloadedName=*/"sf_mm_s_u", /*RequiredExtensions=*/"xsfmm32a8i", /*PrototypeIndex=*/211, /*SuffixIndex=*/213, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_u_s_w4", /*OverloadedName=*/"sf_mm_u_s", /*RequiredExtensions=*/"xsfmm32a8i", /*PrototypeIndex=*/204, /*SuffixIndex=*/206, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_s_s_w4", /*OverloadedName=*/"sf_mm_s_s", /*RequiredExtensions=*/"xsfmm32a8i", /*PrototypeIndex=*/218, /*SuffixIndex=*/61, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_f_f_w2", /*OverloadedName=*/"sf_mm_f_f_w2", /*RequiredExtensions=*/"xsfmm32a16f", /*PrototypeIndex=*/218, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/32, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_f_f_w2", /*OverloadedName=*/"sf_mm_f_f_w2", /*RequiredExtensions=*/"xsfmm32a16f", /*PrototypeIndex=*/218, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/16, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_f_f_w1", /*OverloadedName=*/"sf_mm_f_f_w1", /*RequiredExtensions=*/"xsfmm32a32f", /*PrototypeIndex=*/218, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/64, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_e5m2_e5m2_w4", /*OverloadedName=*/"sf_mm_e5m2_e5m2", /*RequiredExtensions=*/"xsfmm32a8f", /*PrototypeIndex=*/197, /*SuffixIndex=*/85, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_e5m2_e4m3_w4", /*OverloadedName=*/"sf_mm_e5m2_e4m3", /*RequiredExtensions=*/"xsfmm32a8f", /*PrototypeIndex=*/197, /*SuffixIndex=*/85, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_e4m3_e5m2_w4", /*OverloadedName=*/"sf_mm_e4m3_e5m2", /*RequiredExtensions=*/"xsfmm32a8f", /*PrototypeIndex=*/197, /*SuffixIndex=*/85, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_e4m3_e4m3_w4", /*OverloadedName=*/"sf_mm_e4m3_e4m3", /*RequiredExtensions=*/"xsfmm32a8f", /*PrototypeIndex=*/197, /*SuffixIndex=*/85, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/2, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/1, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_mm_f_f_w1", /*OverloadedName=*/"sf_mm_f_f_w1", /*RequiredExtensions=*/"xsfmm64a64f", /*PrototypeIndex=*/218, /*SuffixIndex=*/6, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/7, /*SuffixLength=*/1, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/128, /*Log2LMULMask=*/64, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vsettk", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/13, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vsettm", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/13, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vsettn", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/13, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
{/*Name=*/"sf_vsettnt", /*OverloadedName=*/nullptr, /*RequiredExtensions=*/"xsfmmbase", /*PrototypeIndex=*/13, /*SuffixIndex=*/0, /*OverloadedSuffixIndex=*/0, /*PrototypeLength=*/4, /*SuffixLength=*/0, /*OverloadedSuffixSize=*/0, /*TypeRangeMask=*/4, /*Log2LMULMask=*/8, /*NF=*/1, /*HasMasked=*/0, /*HasVL=*/0, /*HasMaskedOffOperand=*/1, /*HasTailPolicy=*/1, /*HasMaskPolicy=*/1, /*HasFRMRoundModeOp=*/0, /*AltFmt=*/0,/*IsTuple=*/0, /*UnMaskedPolicyScheme=*/SchemeNone, /*MaskedPolicyScheme=*/HasPolicyOperand, },
#endif
